(function() {

    function Ring(c, options) {

        this.cxt = c.getContext("2d");

        this.x = c.width / 2;
        this.y = c.width / 2;
        this.ringLineWidth = options.ringLineWidth;
        this.showText = options.showText;
        this.showSubText = options.showSubText;
        //要显示的值
        this.value = options.value;
        //要求是一个百分比数，最大是1
        this.ringColor = options.ringColor;
        this.ringDefaultColor = "['green', 'red']";

        this.ringWaiColor = options.ringWaiColor;
        this.ringWaiDefaultColor = "['green', 'red']";
        //是否需要圆角
        this.ifFillet = options.ifFillet;

        this.fillColor = options.fillColor;
        //中间填充色
        this.Font = options.Font;
        this.FontSize = options.FontSize;
        this.FontColor = options.FontColor;
        this.SubFont = options.SubFont;
        this.SubFontColor = options.SubFontColor;

    }


    Ring.prototype.draw = function() {

        var _this = this;

        _drawWaiCircle(this);

        _drawCircle(_this);

        _drawFill(_this);

        _drawText(_this);

    }
    function _drawWaiCircle(obj) {
        obj.cxt.beginPath();

        var _x = obj.x;
        var _y = obj.y;
        var _r = _x - obj.ringLineWidth / 2;

        var _endV = (360 * obj.value - 90) * Math.PI / 180;
        var _beginV = -90 * Math.PI / 180;

        obj.cxt.arc(_x, _y, _r, _beginV, _endV, "wise");

        obj.cxt.lineWidth = obj.ringLineWidth;

        var gradient = obj.cxt.createLinearGradient(0, 0, obj.x * 2, 0);

        if (null == obj.ringWaiColor) {
            obj.ringWaiColor = obj.ringWaiDefaultColor;
        }

        if (obj.ringWaiColor.length == 1) {
            gradient.addColorStop("0", obj.ringWaiColor[0]);

        } else {

            for (var i = 0; i < obj.ringWaiColor.length; i++) {
                var v = i * 1 / (obj.ringWaiColor.length - 1);
                gradient.addColorStop(v.toString(), obj.ringWaiColor[i]);
            }
        }

        obj.cxt.strokeStyle = gradient;
        obj.cxt.stroke();
        obj.cxt.closePath();
    }

    function _drawCircle(obj) {
        obj.cxt.beginPath();

        var _x = obj.x;
        var _y = obj.y;
        var _r = _x - obj.ringLineWidth / 2;

        var _beginV = (360 * obj.value - 90) * Math.PI / 180;
        var _endV = -90 * Math.PI / 180;

        obj.cxt.arc(_x, _y, _r, _beginV, _endV, "wise");

        obj.cxt.lineWidth = obj.ringLineWidth;

        var gradient = obj.cxt.createLinearGradient(0, 0, obj.x * 2, 0);

        if (null == obj.ringColor) {
            obj.ringColor = obj.ringDefaultColor;
        }

        if (obj.ringColor.length == 1) {
            gradient.addColorStop("0", obj.ringColor[0]);

        } else {

            for (var i = 0; i < obj.ringColor.length; i++) {
                var v = i * 1 / (obj.ringColor.length - 1);
                gradient.addColorStop(v.toString(), obj.ringColor[i]);
            }
        }

        obj.cxt.strokeStyle = gradient;
        obj.cxt.stroke();
        obj.cxt.closePath();

        // 画圆角
        if (obj.ifFillet && obj.value > 0) {

            obj.cxt.beginPath();
            var _x = obj.x;
            var _y = obj.ringLineWidth / 2;
            var _r = obj.ringLineWidth / 2;
            obj.cxt.arc(_x, _y, _r, 0, 360, false);
            obj.cxt.fillStyle = gradient;
            obj.cxt.fill();
            obj.cxt.closePath();

            obj.cxt.beginPath();
            var jd = (360 * obj.value - 90) * Math.PI / 180;
            var r = obj.x - obj.ringLineWidth / 2
            var _x = obj.x + r * Math.cos(jd);
            var _y = obj.x + r * Math.sin(jd);
            var _r = obj.ringLineWidth / 2;
            obj.cxt.arc(_x, _y, _r, 0, 360, false);
            obj.cxt.fillStyle = gradient;
            obj.cxt.fill();
            obj.cxt.closePath();
        }
    }

    function _drawFill(obj) {
        obj.cxt.beginPath();

        var _x = obj.x;
        var _y = obj.y;
        var _r = _x - obj.ringLineWidth;

        obj.cxt.arc(_x, _y, _r, 0, 360, false);
        obj.cxt.fillStyle = obj.fillColor;

        obj.cxt.fill();
        obj.cxt.closePath();
    }

    function _drawText(obj) {

        obj.cxt.beginPath();
        obj.cxt.font = obj.Font;

        obj.cxt.fillStyle = obj.FontColor;
        obj.cxt.textAlign = 'center';
        obj.cxt.textBaseline = 'middle';
        
        if (null != obj.showSubText && obj.showSubText.length > 0) {
            obj.cxt.fillText(obj.showText, obj.x, obj.y - obj.FontSize / 2);
        } else {
            obj.cxt.fillText(obj.showText, obj.x, obj.y);
        }

        obj.cxt.closePath();

        if (null != obj.showSubText && obj.showSubText.length > 0) {
            obj.cxt.beginPath();

            obj.cxt.font = obj.SubFont;

            obj.cxt.fillStyle = obj.SubFontColor;
            obj.cxt.textAlign = 'center';
            obj.cxt.textBaseline = 'middle';
            obj.cxt.fillText(obj.showSubText, obj.x, obj.y + obj.FontSize / 2);
            obj.cxt.closePath();
        }
    }


    this.Ring = Ring;

})();
